# Fiddle


Fiddle is a Python-first configuration library particularly well suited to ML
applications. Fiddle enables deep configurability of parameters in a program,
while allowing configuration to be expressed in readable and maintainable Python
code.

Additional details can be found in the [documentation].

[documentation]: https://github.com/google/fiddle/tree/main/docs/index.md


### Setup


Install Fiddle with pip:

```shell
pip install fiddle-config
```

Install Fiddle from source:

```shell
git clone https://github.com/google/fiddle
cd fiddle
python -m setup.py install
```

Import Fiddle:

```python
import fiddle as fdl
```
